@@ -1,5 +1,3 @@
-// -*- mode: js; js-indent-level: 4; indent-tabs-mode: nil -*-
-
 import Clutter from 'gi://Clutter';
 import Gio from 'gi://Gio';
 import GLib from 'gi://GLib';
@@ -410,7 +408,7 @@ class WorldClocksSection extends St.Button {
 
         let layout = this._grid.layout_manager;
         const title = this._locations.length === 0
-            ? _('Add world clocks…')
+            ? _('Add World Clocks…')
             : _('World Clocks');
         const header = new St.Label({
             style_class: 'world-clocks-header',
@@ -711,9 +709,9 @@ class WeatherSection extends St.Button {
         }
 
         if (info.network_error())
-            this._setStatusLabel(_('Go online for weather information'));
+            this._setStatusLabel(_('Go Online for Weather Information'));
         else
-            this._setStatusLabel(_('Weather information is currently unavailable'));
+            this._setStatusLabel(_('Weather Information Unavailable'));
     }
 
     _sync() {
@@ -725,7 +723,7 @@ class WeatherSection extends St.Button {
         if (this._weatherClient.hasLocation)
             this._titleLabel.text = _('Weather');
         else
-            this._titleLabel.text = _('Select weather location…');
+            this._titleLabel.text = _('Select Weather Location…');
 
         if (this._weatherClient.hasLocation)
             this._titleLabel.remove_style_class_name('no-location');
