@@ -1296,7 +1296,7 @@ export function getSystemSource() {
     if (!systemNotificationSource) {
         systemNotificationSource = new Source({
             title: _('System'),
-            iconName: 'emblem-system-symbolic',
+            iconName: 'cog-wheel-symbolic',
         });
 
         systemNotificationSource.connect('destroy', () => {
