@@ -531,6 +531,12 @@ export const Switch = GObject.registerClass({
 });
 
 export const PopupSwitchMenuItem = GObject.registerClass({
+    Properties: {
+        'state': GObject.ParamSpec.boolean(
+            'state', null, null,
+            GObject.ParamFlags.READWRITE,
+            false),
+    },
     Signals: {'toggled': {param_types: [GObject.TYPE_BOOLEAN]}},
 }, class PopupSwitchMenuItem extends PopupBaseMenuItem {
     _init(text, active, params) {
@@ -547,7 +553,7 @@ export const PopupSwitchMenuItem = GObject.registerClass({
         this.bind_property('reactive', this._switch, 'reactive', GObject.BindingFlags.SYNC_CREATE);
 
         this.accessible_role = Atk.Role.CHECK_MENU_ITEM;
-        this.checkAccessibleState();
+        this._checkAccessibleState();
         this.label_actor = this.label;
 
         this.add_child(this.label);
@@ -578,7 +584,7 @@ export const PopupSwitchMenuItem = GObject.registerClass({
             this.reactive = true;
             this.accessible_role = Atk.Role.CHECK_MENU_ITEM;
         }
-        this.checkAccessibleState();
+        this._checkAccessibleState();
     }
 
     activate(event) {
@@ -602,17 +608,24 @@ export const PopupSwitchMenuItem = GObject.registerClass({
         return this._switch.state;
     }
 
+    set state(state) {
+        if (this._switch.state === state)
+            return;
+
+        this._switch.set({state});
+    }
+
     setToggleState(state) {
-        this._switch.state = state;
-        this.checkAccessibleState();
+        this.set({state});
     }
 
     _onToggled() {
         this.emit('toggled', this._switch.state);
-        this.checkAccessibleState();
+        this.notify('state');
+        this._checkAccessibleState();
     }
 
-    checkAccessibleState() {
+    _checkAccessibleState() {
         switch (this.accessible_role) {
         case Atk.Role.CHECK_MENU_ITEM:
             if (this._switch.state)
