@@ -1,5 +1,3 @@
-// -*- mode: js; js-indent-level: 4; indent-tabs-mode: nil -*-
-
 import GdkPixbuf from 'gi://GdkPixbuf';
 import Gio from 'gi://Gio';
 import GLib from 'gi://GLib';
@@ -79,7 +77,7 @@ export function loadRemoteSearchProviders(searchSettings) {
 
         try {
             keyfile.load_from_file(path, 0);
-        } catch (e) {
+        } catch {
             return;
         }
 
@@ -101,7 +99,7 @@ export function loadRemoteSearchProviders(searchSettings) {
                 appInfo = Gio.DesktopAppInfo.new(desktopId);
                 if (!appInfo.should_show())
                     return;
-            } catch (e) {
+            } catch {
                 log(`Ignoring search provider ${path}: missing DesktopId`);
                 return;
             }
@@ -109,14 +107,14 @@ export function loadRemoteSearchProviders(searchSettings) {
             let autoStart = true;
             try {
                 autoStart = keyfile.get_boolean(group, 'AutoStart');
-            } catch (e) {
+            } catch {
                 // ignore error
             }
 
             let version = '1';
             try {
                 version = keyfile.get_string(group, 'Version');
-            } catch (e) {
+            } catch {
                 // ignore error
             }
 
@@ -128,7 +126,7 @@ export function loadRemoteSearchProviders(searchSettings) {
             remoteProvider.defaultEnabled = true;
             try {
                 remoteProvider.defaultEnabled = !keyfile.get_boolean(group, 'DefaultDisabled');
-            } catch (e) {
+            } catch {
                 // ignore error
             }
 
