@@ -1,5 +1,3 @@
-// -*- mode: js; js-indent-level: 4; indent-tabs-mode: nil -*-
-
 import Clutter from 'gi://Clutter';
 import Gio from 'gi://Gio';
 import GLib from 'gi://GLib';
@@ -72,6 +70,7 @@ class RunDialog extends ModalDialog.ModalDialog {
         ShellEntry.addContextMenu(entry);
 
         this._entryText = entry.clutter_text;
+        this._entryText.activatable = false;
         content.add_child(entry);
         this.setInitialKeyFocus(this._entryText);
 
@@ -84,6 +83,7 @@ class RunDialog extends ModalDialog.ModalDialog {
         content.add_child(this._descriptionLabel);
 
         this._commandError = false;
+        this._pressedKey = null;
 
         this._pathCompleter = new Gio.FilenameCompleter();
 
@@ -91,14 +91,6 @@ class RunDialog extends ModalDialog.ModalDialog {
             gsettingsKey: HISTORY_KEY,
             entry: this._entryText,
         });
-        this._entryText.connect('activate', o => {
-            this.popModal();
-            this._run(o.get_text(),
-                Clutter.get_current_event().get_state() & Clutter.ModifierType.CONTROL_MASK);
-            if (!this._commandError ||
-                !this.pushModal())
-                this.close();
-        });
         this._entryText.connect('key-press-event', (o, e) => {
             let symbol = e.get_key_symbol();
             if (symbol === Clutter.KEY_Tab) {
@@ -114,6 +106,14 @@ class RunDialog extends ModalDialog.ModalDialog {
                     o.set_cursor_position(text.length + postfix.length);
                 }
                 return Clutter.EVENT_STOP;
+            } else if ([Clutter.KEY_Return, Clutter.KEY_KP_Enter, Clutter.KEY_ISO_Enter].includes(symbol)) {
+                this.popModal();
+                this._run(o.get_text(),
+                    Clutter.get_current_event().get_state() & Clutter.ModifierType.CONTROL_MASK);
+                if (!this._commandError ||
+                    !this.pushModal())
+                    this.close();
+                return Clutter.EVENT_STOP;
             }
             return Clutter.EVENT_PROPAGATE;
         });
@@ -122,8 +122,19 @@ class RunDialog extends ModalDialog.ModalDialog {
         });
     }
 
+    vfunc_key_press_event(event) {
+        this._pressedKey = event.get_key_symbol();
+    }
+
     vfunc_key_release_event(event) {
-        if (event.get_key_symbol() === Clutter.KEY_Escape) {
+        const pressedKey = this._pressedKey;
+        this._pressedKey = null;
+
+        const key = event.get_key_symbol();
+        if (key !== pressedKey)
+            return Clutter.EVENT_PROPAGATE;
+
+        if (key === Clutter.KEY_Escape) {
             this.close();
             return Clutter.EVENT_STOP;
         }
