@@ -10,7 +10,6 @@
 #include <stdlib.h>
 #include <string.h>
 
-#include <cogl-pango/cogl-pango.h>
 #include <clutter/clutter.h>
 #include <glib-unix.h>
 #include <glib/gi18n-lib.h>
@@ -222,7 +221,7 @@ shell_introspection_init (void)
 {
 
   g_irepository_prepend_search_path (MUTTER_TYPELIB_DIR);
-  g_irepository_prepend_search_path (GNOME_SHELL_PKGLIBDIR);
+  g_irepository_prepend_search_path (SHELL_TYPELIB_DIR);
 
   /* We need to explicitly add the directories where the private libraries are
    * installed to the GIR's library path, so that they can be found at runtime
@@ -237,20 +236,6 @@ shell_introspection_init (void)
 #endif
 }
 
-static void
-shell_fonts_init (void)
-{
-  CoglPangoFontMap *fontmap;
-
-  /* Disable text mipmapping; it causes problems on pre-GEM Intel
-   * drivers and we should just be rendering text at the right
-   * size rather than scaling it. If we do effects where we dynamically
-   * zoom labels, then we might want to reconsider.
-   */
-  fontmap = COGL_PANGO_FONT_MAP (clutter_get_font_map ());
-  cogl_pango_font_map_set_use_mipmapping (fontmap, FALSE);
-}
-
 static void
 shell_profiler_init (void)
 {
@@ -360,8 +345,6 @@ shell_perf_log_init (void)
 static void
 shell_a11y_init (void)
 {
-  cally_accessibility_init ();
-
   if (clutter_get_accessibility_enabled () == FALSE)
     {
       g_warning ("Accessibility: clutter has no accessibility enabled"
@@ -685,7 +668,6 @@ main (int argc, char **argv)
   shell_a11y_init ();
   shell_perf_log_init ();
   shell_introspection_init ();
-  shell_fonts_init ();
 
   g_log_set_writer_func (default_log_writer, NULL, NULL);
 
