@@ -353,9 +353,7 @@ shell_keyring_prompt_class_init (ShellKeyringPromptClass *klass)
    * Whether the password entry is visible or not.
    */
   props[PROP_PASSWORD_VISIBLE] =
-    g_param_spec_boolean ("password-visible",
-                          "Password visible",
-                          "Password field is visible",
+    g_param_spec_boolean ("password-visible", NULL, NULL,
                           FALSE,
                           G_PARAM_READABLE | G_PARAM_STATIC_STRINGS);
 
@@ -365,9 +363,7 @@ shell_keyring_prompt_class_init (ShellKeyringPromptClass *klass)
     * Whether the password confirm entry is visible or not.
     */
   props[PROP_CONFIRM_VISIBLE] =
-    g_param_spec_boolean ("confirm-visible",
-                          "Confirm visible",
-                          "Confirm field is visible",
+    g_param_spec_boolean ("confirm-visible", NULL, NULL,
                           FALSE,
                           G_PARAM_READABLE | G_PARAM_STATIC_STRINGS);
 
@@ -377,9 +373,7 @@ shell_keyring_prompt_class_init (ShellKeyringPromptClass *klass)
    * Whether the warning label is visible or not.
    */
   props[PROP_WARNING_VISIBLE] =
-    g_param_spec_boolean ("warning-visible",
-                          "Warning visible",
-                          "Warning is visible",
+    g_param_spec_boolean ("warning-visible", NULL, NULL,
                           FALSE,
                           G_PARAM_READABLE | G_PARAM_STATIC_STRINGS);
 
@@ -389,9 +383,7 @@ shell_keyring_prompt_class_init (ShellKeyringPromptClass *klass)
    * Whether the choice check box is visible or not.
    */
   props[PROP_CHOICE_VISIBLE] =
-    g_param_spec_boolean ("choice-visible",
-                          "Choice visible",
-                          "Choice is visible",
+    g_param_spec_boolean ("choice-visible", NULL, NULL,
                           FALSE,
                           G_PARAM_READABLE | G_PARAM_STATIC_STRINGS);
 
@@ -401,9 +393,7 @@ shell_keyring_prompt_class_init (ShellKeyringPromptClass *klass)
    * Text field for password
    */
   props[PROP_PASSWORD_ACTOR] =
-    g_param_spec_object ("password-actor",
-                         "Password actor",
-                         "Text field for password",
+    g_param_spec_object ("password-actor", NULL, NULL,
                          CLUTTER_TYPE_TEXT,
                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
@@ -413,9 +403,7 @@ shell_keyring_prompt_class_init (ShellKeyringPromptClass *klass)
    * Text field for confirmation password
    */
   props[PROP_CONFIRM_ACTOR] =
-    g_param_spec_object ("confirm-actor",
-                         "Confirm actor",
-                         "Text field for confirming password",
+    g_param_spec_object ("confirm-actor", NULL, NULL,
                          CLUTTER_TYPE_TEXT,
                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
