@@ -25,8 +25,7 @@
 #error "Only <st/st.h> can be included directly.h"
 #endif
 
-#ifndef __ST_WIDGET_H__
-#define __ST_WIDGET_H__
+#pragma once
 
 #include <clutter/clutter.h>
 #include <st/st-types.h>
@@ -154,5 +153,3 @@ void                  st_widget_add_accessible_state     (StWidget    *widget,
 void                  st_widget_remove_accessible_state  (StWidget    *widget,
                                                           AtkStateType state);
 G_END_DECLS
-
-#endif /* __ST_WIDGET_H__ */
